@@ -1,6 +1,7 @@
 """Contains the base class for PPP nodes."""
 
 import json
+import logging
 
 from . import exceptions
 
@@ -34,7 +35,7 @@ class AbstractNode:
             assert attributes.pop('type') == self.type
         unknown_keys = set(attributes) - set(self._possible_attributes)
         if unknown_keys:
-            raise TypeError('%s node got unknown attributes: %s' %
+            logging.warning('%s node got unknown attributes: %s' %
                             (self._type, unknown_keys))
 
     @property
